<?php

namespace Drupal\suggestion\Form;

use Drupal\Core\Batch\BatchBuilder;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\suggestion\SuggestionHelper as Helper;
use Drupal\suggestion\SuggestionStorage as Sql;

/**
 * Helper methods to build the Suggestion Index batch definition.
 */
class BatchHelper {

  /**
   * Initialize the batch process.
   */
  public static function create(): void {
    $batch = new BatchBuilder();
    $batch->setTitle(new TranslatableMarkup('Indexing suggestions'));
    $batch->setErrorMessage(new TranslatableMarkup('Error indexing suggestions'));
    $batch->addOperation([__CLASS__, 'process'], [50]);
    $batch->setInitMessage(new TranslatableMarkup('Preparing to index suggestions.'));
    $batch->setProgressMessage('');

    batch_set($batch->toArray());
  }

  /**
   * Process a batch.
   *
   * @param int $batch_size
   *   The number of node titles to index in one batch.
   * @param array $context
   *   The batch context.
   */
  public static function process(int $batch_size, array &$context): void {
    if (empty($context['sandbox']['batch_size'])) {
      $context['sandbox']['batch_size'] = $batch_size;
      $context['sandbox']['last_nid'] = 0;
      $context['sandbox']['total'] = Sql::getTotalTitleCount();
    }
    $context['sandbox']['last_nid'] = Helper::index($context['sandbox']['last_nid'], $context['sandbox']['batch_size']);
    $context['sandbox']['progress'] = !empty($context['sandbox']['progress']) ? $context['sandbox']['progress'] + $batch_size : $batch_size;

    $args = [
      '@current' => $context['sandbox']['progress'],
      '@total'   => $context['sandbox']['total'],
    ];
    $context['message'] = new TranslatableMarkup('Indexing @current out of @total suggestion titles.', $args);

    $context['finished'] = $context['sandbox']['progress'] / $context['sandbox']['total'];
  }

}
